@@ -7,6 +7,7 @@ from krx_hj3415 import krx
 import pandas as pd
 import time
 from multiprocessing import Process, cpu_count, Queue
+import datetime
 
 import logging
 
@@ -288,9 +289,13 @@ def _make_df_part(codes: list, q):
     q.put(df)
 
 
-def get_df() -> pd.DataFrame:
+def get_df(refresh: bool = False) -> pd.DataFrame:
     """ 멀티프로세싱을 사용하여 전체 종목의 eval 을 데이터프레임으로 만들어 반환
 
+    기본값으로 refresh 는 False 로 설정되어 당일자의 저장된 데이터프레임이 있으면 새로 생성하지 않고 DB를 이용한다.
+
+    Args:
+        refresh (bool): 저장된 db 자료를 이용하지 않고 강제로 리프레시하는 경우
     """
     def _code_divider(entire_codes: list) -> tuple:
         # 전체 종목코드를 리스트로 넣으면 cpu 코어에 맞춰 나눠준다.
@@ -311,30 +316,38 @@ def get_df() -> pd.DataFrame:
         divided_list = _split_list(entire_codes, wanted_parts=n)
         return n, divided_list
 
-    print(setting.load())
-    codes = mongo.Corps.get_all_corps()
+    today_str = datetime.datetime.today().strftime('%Y%m%d')
+    df = mongo.EvalByDate(date=today_str).get_data()
+    if refresh or len(df) == 0:
+        print(setting.load())
+        codes = mongo.Corps.get_all_corps()
 
-    print('*' * 25, f"Eval all using multiprocess", '*' * 25)
-    print(f'Total {len(codes)} items..')
-    logger.info(codes)
-    n, divided_list = _code_divider(codes)
+        print('*' * 25, f"Eval all using multiprocess", '*' * 25)
+        print(f'Total {len(codes)} items..')
+        logger.info(codes)
+        n, divided_list = _code_divider(codes)
 
-    start_time = time.time()
-    q = Queue()
-    ths = []
-    for i in range(n):
-        ths.append(Process(target=_make_df_part, args=(divided_list[i], q)))
-    for i in range(n):
-        ths[i].start()
-    df_list = []
-    for i in range(n):
-        df_list.append(q.get())
-    # 부분데이터프레임들을 하나로 합침
-    final_df = pd.concat(df_list, ignore_index=True)
-    for i in range(n):
-        ths[i].join()
-    print(f'Total spent time : {round(time.time() - start_time, 2)} sec.')
-    logger.debug(final_df)
+        start_time = time.time()
+        q = Queue()
+        ths = []
+        for i in range(n):
+            ths.append(Process(target=_make_df_part, args=(divided_list[i], q)))
+        for i in range(n):
+            ths[i].start()
+        df_list = []
+        for i in range(n):
+            df_list.append(q.get())
+        # 부분데이터프레임들을 하나로 합침
+        final_df = pd.concat(df_list, ignore_index=True)
+        for i in range(n):
+            ths[i].join()
+        print(f'Total spent time : {round(time.time() - start_time, 2)} sec.')
+        logger.debug(final_df)
+        print(f"Save to mongo db(db: eval col: {today_str}")
+        mongo.EvalByDate(date=today_str).save(final_df)
+    else:
+        print(f"Use saved dataframe from mongo db..")
+        final_df = mongo.EvalByDate(date=today_str).get_data()
     return final_df
 
 
